@@ -3,13 +3,14 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.64';
+our $VERSION = '1.68';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
 use DateTime::Locale 0.45;
 use DateTime::TimeZone 0.79;
-use Params::Validate 1.20 qw( validate SCALAR BOOLEAN OBJECT CODEREF );
+use Params::Validate 1.20
+    qw( validate SCALAR BOOLEAN OBJECT CODEREF HASHREF );
 use Try::Tiny;
 
 use Exporter qw( import );
@@ -24,11 +25,15 @@ use constant PERL_58 => $] < 5.010;
 
 {
     my $spec = {
-        pattern => { type => SCALAR },
+        pattern   => { type => SCALAR },
         time_zone => {
             type     => SCALAR | OBJECT,
             optional => 1,
         },
+        zone_map => {
+            type    => HASHREF,
+            default => {},
+        },
         locale => {
             type    => SCALAR | OBJECT,
             default => DateTime::Locale->load('en'),
@@ -70,7 +75,7 @@ use constant PERL_58 => $] < 5.010;
 
         my $self = bless {
             %args,
-            zone_map => $class->_build_zone_map,
+            zone_map => $class->_build_zone_map( $args{zone_map} ),
         }, $class;
 
         # Forces a check that the pattern is valid
@@ -191,8 +196,16 @@ use constant PERL_58 => $] < 5.010;
         'UTC'    => '+0000',
     );
 
+    for my $i ( map { sprintf( '%02d', $_ ) } 1 .. 12 ) {
+        $zone_map{ '-' . $i } = '-' . $i . '00';
+        $zone_map{ '+' . $i } = '+' . $i . '00';
+    }
+
     sub _build_zone_map {
-        return \%zone_map;
+        return {
+            %zone_map,
+            %{ $_[1] },
+        };
     }
 }
 
@@ -320,7 +333,7 @@ sub _build_parser {
     }
 
     return {
-        regex  => qr/\A\s*$regex/,
+        regex  => qr/(?:\A\s|\b)*$regex/,
         fields => \@fields,
     };
 }
@@ -415,7 +428,7 @@ sub _build_parser {
             field => 'time_zone_offset',
         },
         Z => {
-            regex => qr/[a-zA-Z]{1,6}/,
+            regex => qr/[a-zA-Z]{1,6}|[\-\+][0-9]{2}/,
             field => 'time_zone_abbreviation',
         },
     );
@@ -1020,13 +1033,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.64
+version 1.68
 
 =head1 SYNOPSIS
 
@@ -1052,9 +1067,6 @@ version 1.64
         on_error  => 'croak',
     );
 
-    # Will throw an exception
-    $newpattern = $strp->pattern('%Q');
-
     # Do something else when things go wrong:
     my $strp = DateTime::Format::Strptime->new(
         pattern   => '%T',
@@ -1070,8 +1082,6 @@ reverse of C<strftime(3)>, for C<DateTime>. While C<strftime> takes a
 C<DateTime> and a pattern and returns a string, C<strptime> takes a string and
 a pattern and returns the C<DateTime> object associated.
 
-=encoding UTF-8
-
 =for Pod::Coverage parse_duration format_duration
 
 =head1 METHODS
@@ -1092,6 +1102,16 @@ This is the pattern to use for parsing. This is required.
 
 The default time zone to use for objects returned from parsing.
 
+=item * zone_map
+
+Some time zone abbreviations are ambiguous (e.g. PST, EST, EDT). By default,
+the parser will die when it parses an ambiguous abbreviation. You may specify
+a C<zone_map> parameter as a hashref to map zone abbreviations however you like:
+
+    zone_map => { PST => '-0800', EST => '-0600' }
+
+Note that you can also override non-ambiguous mappings if you want to as well.
+
 =item * locale
 
 The locale to use for objects returned from parsing.
@@ -1327,13 +1347,6 @@ C<strftime()> method, but can be passed to C<format_datetime()>.
 
 This module was created by Rick Measham.
 
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-datetime-format-strptime@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>. I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
-
 =head1 SEE ALSO
 
 C<datetime@perl.org> mailing list.
@@ -1342,6 +1355,38 @@ http://datetime.perl.org/
 
 L<perl>, L<DateTime>, L<DateTime::TimeZone>, L<DateTime::Locale>
 
+=head1 BUGS
+
+Please report any bugs or feature requests to
+C<bug-datetime-format-strptime@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>. I will be notified, and then you'll automatically be
+notified of progress on your bug as I make changes.
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Format-Strptime>
+(or L<bug-datetime-format-strptime@rt.cpan.org|mailto:bug-datetime-format-strptime@rt.cpan.org>).
+
+There is a mailing list available for users of this distribution,
+L<mailto:datetime@perl.org>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time (let's all have a chuckle at that together).
+
+To donate, log into PayPal and send money to autarch@urth.org, or use the
+button at L<http://www.urth.org/~autarch/fs-donation.html>.
+
 =head1 AUTHORS
 
 =over 4
@@ -1356,15 +1401,25 @@ Rick Measham <rickm@cpan.org>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords D. Ilmari Mannsåker
+=for stopwords D. Ilmari Mannsåker key-amb
+
+=over 4
+
+=item *
 
 D. Ilmari Mannsåker <ilmari.mannsaker@net-a-porter.com>
 
-=head1 COPYRIGHT AND LICENSE
+=item *
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+key-amb <yasutake.kiyoshi@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is Copyright (c) 2015 - 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
